@@ -7,7 +7,7 @@ Coord <- proto(TopLevel, expr={
   # Rescaling at coord level should not be clipped: this is what 
   # makes zooming work
   rescale_var <- function(., data, range, clip = FALSE) {
-    rescale(data, 0:1, range, clip = clip)  
+    rescale(data, 0:1, range, clip = clip)
   }
   
   munch <- function(., data, details, npieces=50) {
@@ -34,6 +34,10 @@ Coord <- proto(TopLevel, expr={
     )
   }
   
+  compute_aspect <- function(., ranges) {
+    NULL
+  }
+  
   labels <- function(., scales) {
     scales
   }
