@@ -46,7 +46,7 @@ Stat <- proto(TopLevel, expr={
       )
     }, stats, groups, SIMPLIFY=FALSE)
 
-    do.call("rbind.fill", stats)
+    do.call(plyr::rbind.fill, stats)
   }
 
 
