@@ -2,7 +2,7 @@
 suppressMessages(library(ggplot2, warn.conflicts = FALSE))
 
 # Find path of this file and source in R files
-frame_files <- compact(llply(sys.frames(), function(x) x$ofile))
+frame_files <- plyr::compact(plyr::llply(sys.frames(), function(x) x$ofile))
 PATH <- dirname(frame_files[[length(frame_files)]])
 
 paths <- dir(file.path(PATH, "R"), full.name=T)
@@ -13,7 +13,7 @@ loc <- Sys.setlocale("LC_COLLATE", "C")
 paths <- paths[order(paths)]
 Sys.setlocale("LC_COLLATE", loc)
 
-l_ply(paths, source)
+plyr::l_ply(paths, source)
 
 # Regenerate and load accessors for geoms etc.
 accessors_print(file.path(PATH, "R", "xxx.r"))
